# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.2] - 2024-09-17
### Added
- 5 new methods
	1. Pour-over
	2. Auto drip
	3. Cold brew
	4. Cold brew concentrate
	5. Moka pot
- `is_int` function
- `filter_params` function
### Changed
- `README.md` updated
- `--coffee-ratio` type changed from `int` to `float`
- `--water-ratio` type changed from `int` to `float`
- `coffee_calc` function renamed to `calc_coffee`
- `print_message` function updated
- Test system modified
## [0.1] - 2024-09-02
### Added
- 6 new methods
	1. V60
	2. Espresso
	3. Chemex
	4. French-press
	5. Siphon
	6. Custom

[Unreleased]: https://github.com/sepandhaghighi/mycoffee/compare/v0.2...dev
[0.2]: https://github.com/sepandhaghighi/mycoffee/compare/v0.1...v0.2
[0.1]: https://github.com/sepandhaghighi/mycoffee/compare/c2d0bb4...v0.1



